%%%%%%%%%%%%%%%%%%%%%%
%%                                                         %%
%% ICCCM2023 class for LaTeX files   %%
%%                                                         %%
%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{icccm2023}
\DeclareOption{11pt}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[10pt]{article}
\RequirePackage{calc}
\RequirePackage{indentfirst}
\usepackage{times}

%% Title
\renewcommand{\@maketitle}
{
 \thispagestyle{plain}
 \begin{flushleft}
{\fontsize{14}{14}\selectfont
   \@title
   \par}
   
  \vspace{12pt}
  
{\@author
   \par}
   
{ \def\and{\\\vspace{14pt}}
   \normalfont\@address
   \par}
   
 \end{flushleft}
 \vspace{0mm}%
 \noindent {{\em Keywords}:\space }{\@keywords \bigskip}
}
% End of \@maketitle

\def\author{\@ifnextchar[{\@getshortauthor}{\@getauthor}}
\def\@getauthor#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\def\@getshortauthor[#1]#2{\gdef\@shortauthor{#1}\gdef\@author{#2}}
\newcommand{\address}[1]{\gdef\@address{#1}}
\newcommand{\keywords}[1]{\gdef\@keywords{#1}}
\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}
\newcommand{\heading}[1]{\gdef\@heading{#1}}

\def\sectionLevel{1}
\def\sectionIndent{6mm}
\def\sectionSpaceBefore{0pt}
\def\sectionSpaceAfter{0pt}
\def\sectionStyle{\normalsize}
\renewcommand{\section}{%
  \@startsection{section}{\sectionLevel}{\sectionIndent}{\sectionSpaceBefore}%
                {\sectionSpaceAfter}{\sectionStyle}}%
\def\sectionLevel{2}
\def\sectionIndent{6mm}
\def\sectionSpaceBefore{12pt}
\def\sectionSpaceAfter{1pt}
\def\sectionStyle{\normalsize}
\renewcommand{\refname}{\textit{References}}
\renewcommand{\subsection}{%
  \@startsection{subsection}{\sectionLevel}{\sectionIndent}{\sectionSpaceBefore}%
                {\sectionSpaceAfter}{\sectionStyle}}%
\renewcommand{\@makecaption}[2]{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\normalsize\fontsize{10}{12}\selectfont #1: #2}%
  \ifdim \wd\@tempboxa >\hsize
    \normalsize\fontsize{10}{12}\selectfont #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}
\renewcommand{\baselinestretch}{1.05}
\setlength{\oddsidemargin}{7.6mm}
\setlength{\voffset}{-22mm}
\setlength{\topmargin}{0mm}
\setlength{\headheight}{24.6mm}
\setlength{\headsep}{0mm}
\setlength{\textheight}{200mm}
\setlength{\textwidth}{145mm}
\setlength{\textfloatsep}{12pt}
\setlength{\abovedisplayskip}{6pt}
\setlength{\belowdisplayskip}{6pt}
\setlength{\parindent}{5mm}
\setlength{\abovecaptionskip}{6pt}
\setlength{\belowcaptionskip}{6pt}
\setlength{\itemsep}{0pt}
\AtBeginDocument{%
  \pagestyle{plain}
  \maketitle
  \let\maketitle\relax
}
\endinput